Package Guidelines
==================

.. toctree::
   :maxdepth: 3

   how2package4ioos.md

ioos_pkg_skeleton
=================

What is ioos_pkg_skeleton?
--------------------------

The best module ever written!


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   tutorial.ipynb
   ioos_pkg_skeleton

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
